@@ -1,16 +1,11 @@
 #! /usr/bin/env bash
 
-_build_shared=ON
-if [[ `uname -s` == 'Darwin' ]]; then
-    _build_shared=OFF
-fi
-
 mkdir _build && cd _build
 cmake \
     -DCMAKE_PREFIX_PATH=$PREFIX \
     -DCMAKE_INSTALL_PREFIX=$PREFIX \
     -DCMAKE_BUILD_TYPE=Release \
-    -DCGNS_BUILD_SHARED=$_build_shared \
+    -DCGNS_BUILD_SHARED=ON \
     -DCGNS_USE_SHARED=ON \
     -DCGNS_ENABLE_FORTRAN=OFF \
     -DFORTRAN_NAMING="LOWERCASE_" \
